#
# spec file for package python-opentelemetry-util-http
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-opentelemetry-util-http
Version:        0.50b0
Release:        1.1
Summary:        Instrumentation Tools & Auto Instrumentation for OpenTelemetry Python
License:        Apache-2.0
URL:            https://github.com/open-telemetry/opentelemetry-python/tree/main/opentelemetry-util-http
Source:         https://files.pythonhosted.org/packages/source/o/opentelemetry_util_http/opentelemetry_util_http-%{version}.tar.gz
Source1:        LICENSE
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-opentelemetry-api = 1.29.0
Requires:       python-opentelemetry-instrumentation == %{version}
Requires:       python-opentelemetry-sdk = 1.29.0
Requires:       python-opentelemetry-semantic-conventions == %{version}
Requires:       python-wrapt >= 1.0.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module opentelemetry-api = 1.29.0}
BuildRequires:  %{python_module opentelemetry-instrumentation == %{version}}
BuildRequires:  %{python_module opentelemetry-sdk = 1.29.0}
BuildRequires:  %{python_module opentelemetry-semantic-conventions == %{version}}
BuildRequires:  %{python_module opentelemetry-test-utils == %{version}}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wrapt >= 1.0.0}
# /SECTION
%python_subpackages

%description
Instrumentation Tools & Auto Instrumentation for OpenTelemetry Python

%prep
%setup -q -n opentelemetry_util_http-%{version}

%build
%pyproject_wheel

%install
install -m 644 %{SOURCE1} %{_builddir}/opentelemetry_util_http-%{version}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/opentelemetry/util/http
%{python_sitelib}/opentelemetry_util_http-%{version}.dist-info

%changelog
* Wed Jan  8 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to version 0.50b0
  * `opentelemetry-instrumentation-starlette` Add type hints to the instrumentation
  * `opentelemetry-distro` default to OTLP log exporter.
  * `opentelemetry-instrumentation-sqlalchemy` Update unit tests to run with SQLALchemy 2
  * Add `opentelemetry-instrumentation-openai-v2` to `opentelemetry-bootstrap`
  * `opentelemetry-instrumentation-sqlalchemy` Add sqlcomment to `db.statement` attribute
  * `opentelemetry-instrumentation-dbapi` Add sqlcomment to `db.statement` attribute
  * `opentelemetry-instrumentation-dbapi` instrument_connection accepts optional connect_module
  * `opentelemetry-instrumentation-mysqlclient` Add sqlcommenter support
  * `opentelemetry-instrumentation-pymysql` Add sqlcommenter support
  * `opentelemetry-instrumentation-click`: new instrumentation to trace click commands
  * `opentelemetry-instrumentation-starlette`: Retrieve `meter_provider` key instead of
    `_meter_provider` on `_instrument`
  * `opentelemetry-instrumentation-httpx`: instrument_client is a static method again
  * `opentelemetry-instrumentation-system_metrics`: fix callbacks reading wrong config
  * `opentelemetry-instrumentation-httpx`: Check if mount transport is none before wrap it
  * Replace all instrumentor unit test `assertEqualSpanInstrumentationInfo` calls with
    `assertEqualSpanInstrumentationScope` calls
  * `opentelemetry-instrumentation-sqlalchemy` Fixes engines from `sqlalchemy.engine_from_config`
    not being fully instrumented
  * `opentelemetry-instrumentation-sqlalchemy`: Fix a remaining memory leak in EngineTracer
  * `opentelemetry-instrumentation-sqlite3`: Update documentation on explicit cursor support of tracing
  * `opentelemetry-instrumentation-sqlalchemy` teach instruments version
  * Drop `opentelemetry-instrumentation-test` package from default instrumentation list
  * `opentelemetry-instrumentation-httpx`: remove private unused `_InstrumentedClient`
    and `_InstrumentedAsyncClient` classes
- from version 0.49b0
  * `opentelemetry-instrumentation-openai-v2` Instrumentation for OpenAI >= 0.27.0
  * `opentelemetry-instrumentation-fastapi` Add autoinstrumentation mechanism tests.
  * `opentelemetry-instrumentation-aiokafka` Add instrumentor and auto instrumentation
    support for aiokafka
  * `opentelemetry-instrumentation-redis` Add additional attributes for methods create_index
    and search, rename those spans
  * `opentelemetry-instrumentation` Add support for string based dotted module paths in unwrap
  * `opentelemetry-instrumentation-aiokafka` Wrap `AIOKafkaConsumer.getone()` instead of `AIOKafkaConsumer.__anext__`
  * `opentelemetry-instrumentation-confluent-kafka` Fix to allow `topic` to be extracted from `kwargs` in `produce()`
  * `opentelemetry-instrumentation-system-metrics` Update metric units to conform to UCUM conventions.
  * `opentelemetry-instrumentation-celery` Don't detach context without a None token
  * `opentelemetry-exporter-prometheus-remote-write`: sort labels before exporting
  * `opentelemetry-instrumentation-dbapi` sqlcommenter key values created from PostgreSQL, MySQL systems
  * `opentelemetry-instrumentation-system-metrics`: don't report open file descriptors on Windows
  * Deprecation of pkg_resource in favor of importlib.metadata
  * `opentelemetry-instrumentation` Don't fail distro loading if instrumentor raises ImportError, instead skip them
  * `opentelemetry-instrumentation-httpx` Rewrote instrumentation to use wrapt instead of subclassing
- Update BuildRequires and Requires from pyproject.toml
- Use %%{version} in BuildRequires and Requires for dependencies
* Mon Sep  2 2024 Dirk Müller <dmueller@suse.com>
- specfile fixes
* Fri Aug 30 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Initial build
  * Version 0.48b0
